@@ -84,6 +84,9 @@ class LinuxDevice(NetBoxModel):
     def __str__(self):
         return f'{self.device}'
 
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:linuxdevice", kwargs={"pk": self.pk})
+
 
 class Partition(NetBoxModel):
     drive = models.ForeignKey(
@@ -126,7 +129,7 @@ class Partition(NetBoxModel):
     def docs_url(self):
         return f'https://confluence.ti8m.ch/docs/models/partition/'
 
-    def clean(self, *args, **kwargs):
+    """def clean(self, *args, **kwargs):
         total_allocated_space = Partition.objects.filter(drive=self.drive).aggregate(sum=Sum("size")).get("sum") or 0
         current_partition_size = Partition.objects.filter(drive=self.drive, id=self.pk) \
                                      .aggregate(sum=Sum("size")).get("sum") or 0
@@ -156,7 +159,7 @@ class Partition(NetBoxModel):
                         "size": f"The size of the Partition is bigger than the size of the Hard Drive."
                     }
                 )
-
+"""
     def get_affiliated_physical_volume(self):
         return PhysicalVolume.objects.filter(partition=self).first()
 
