@@ -2,7 +2,7 @@ import logging
 
 from extras.plugins import PluginTemplateExtension
 from netbox_storage.models import PhysicalVolume, LogicalVolume, MountedVolume, StorageConfigurationLinuxVolume, \
-    TemplateConfigurationLinuxVolume, Drive
+    TemplateConfigurationLinuxVolume, Drive, Partition
 
 
 class RelatedDrives(PluginTemplateExtension):
@@ -46,16 +46,24 @@ class TemplateVolumeConfig(PluginTemplateExtension):
     def full_width_page(self):
         obj = self.context.get("object")
 
-        drives_id = TemplateConfigurationLinuxVolume.objects.values('drive').filter(platform=obj)
-        print(drives_id)
-        for drive_id in drives_id:
+        drives = TemplateConfigurationLinuxVolume.objects.values('drive').filter(platform=obj)
+        drives_id = []
+        lonely_drive = []
+        for drive_id in drives:
             print(drive_id['drive'])
+            drives_id.append(drive_id['drive'])
+            if Partition.objects.filter(drive_id=drive_id['drive']).count() == 0:
+                lonely_drive.append(Drive.objects.get(pk__in=drive_id['drive']))
 
-        drives = Drive.objects.filter(pk__in=[1, 2])
+        partitions = Partition.objects.filter(drive_id__in=drives_id)
+        print(f"{Partition.objects.all()}")
+        print(f"Partitions: {partitions}")
+        print(f"drives: {drives_id}")
         return self.render(
             "netbox_storage/inc/template_box.html",
             extra_context={
-                "drives": drives,
+                "lonely_drives": lonely_drive,
+                "partitions": partitions
             }
         )
 
