@@ -1,7 +1,7 @@
 from django.urls import path
 
 from netbox.views.generic import ObjectChangeLogView
-from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, LinuxDevice
 from netbox_storage.views import (
     # Drive View
     DriveListView,
@@ -40,6 +40,8 @@ from netbox_storage.views import (
     MountedVolumeView,
     MountedVolumeDeleteView, LVMAddSimpleView, AddSimpleLinuxVolumeView,
 )
+from netbox_storage.views.linux_device import LinuxDeviceListView, LinuxDeviceEditView, LinuxDeviceBulkImportView, \
+    LinuxDeviceBulkEditView, LinuxDeviceBulkDeleteView, LinuxDeviceView, LinuxDeviceDeleteView
 from netbox_storage.views.template import LVMAddTemplateView, AddTemplateVolumeView, AddTemplateDriveView, \
     AddTemplatePartitionView
 
@@ -116,6 +118,23 @@ urlpatterns = [
         kwargs={"model": MountedVolume},
     ),
     #
+    # MountedVolume urls
+    #
+    path("linuxdevice/", LinuxDeviceListView.as_view(), name="linuxdevice_list"),
+    path("linuxdevice/add/", LinuxDeviceEditView.as_view(), name="linuxdevice_add"),
+    path("linuxdevice/import/", LinuxDeviceBulkImportView.as_view(), name="linuxdevice_import"),
+    path("linuxdevice/edit/", LinuxDeviceBulkEditView.as_view(), name="linuxdevice_bulk_edit"),
+    path("linuxdevice/delete/", LinuxDeviceBulkDeleteView.as_view(), name="linuxdevice_bulk_delete"),
+    path("linuxdevice/<int:pk>/", LinuxDeviceView.as_view(), name="linuxdevice"),
+    path("linuxdevice/<int:pk>/edit/", LinuxDeviceEditView.as_view(), name="linuxdevice_edit"),
+    path("linuxdevice/<int:pk>/delete/", LinuxDeviceDeleteView.as_view(), name="linuxdevice_delete"),
+    path(
+        "linuxdevice/<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="linuxdevice_changelog",
+        kwargs={"model": LinuxDevice},
+    ),
+    #
     # Simple Configuration
     #
     path('lvm-add/', LVMAddSimpleView.as_view(), name='lvm_add'),
